@@ -98,7 +98,10 @@ else
  {
   if(is.numeric(Margin.vec) && length(Margin.vec)<=nrow(Num.C))
    {Margin.vec <- cbind(Margin.vec,Num.C)[,1]}
-  else{stop("Margin.vec must be a single numeric value or numeric vector not longer than nrow of contrasts ")}
+  else{
+    Margin.vec <- Margin.vec[1:nrow(Num.C)]
+    warning( paste("Margin.vec has more elements than there are comparisons. Only the first ", nrow(Num.C)," elements are used!") )
+    }
  }
 
 out<-simtest.ratioI(Response=Response, Treatment=Treatment, alternative=alternative, Margin.vec=Margin.vec, FWER=FWER, Num.Contrast=Num.C, Den.Contrast=Den.C)
